@@ -573,7 +573,7 @@ def Run_Graph_WF_dep(set,sess,self,GO,batch_size,random=True,train=True,drop_out
         sp = OH.fit_transform(i.reshape(-1, 1)).T
         sp = sp.tocoo()
         indices = np.mat([sp.row, sp.col]).T
-        sp = tf.SparseTensorValue(indices, sp.data, sp.shape)
+        sp = tf.compat.v1.SparseTensorValue(indices, sp.data, sp.shape)
 
         # feed_dict = {GO.Y: vars[-1],
         #              GO.X_Freq: self.freq[var_idx],
@@ -635,7 +635,8 @@ def Run_Graph_WF_dep(set,sess,self,GO,batch_size,random=True,train=True,drop_out
         auc = 0.0
     return loss,accuracy,predicted_out,auc
 
-def Run_Graph_WF(set,sess,self,GO,batch_size,batch_size_update,random=True,train=True,drop_out_rate=None,multisample_dropout_rate=None):
+def Run_Graph_WF(set,sess,self,GO,batch_size,batch_size_update,random=True,train=True,drop_out_rate=None,multisample_dropout_rate=None,
+                 subsample=None,subsample_by_freq=False):
     loss = []
     accuracy = []
     predicted_list = []
@@ -646,7 +647,20 @@ def Run_Graph_WF(set,sess,self,GO,batch_size,batch_size_update,random=True,train
     grads = []
     w = []
     for vars in get_batches(set, batch_size=batch_size, random=random):
-        var_idx = np.where(np.isin(self.sample_id, vars[0]))[0]
+        if subsample is None:
+            var_idx = np.where(np.isin(self.sample_id, vars[0]))[0]
+        else:
+            var_idx = []
+            for p in np.unique(vars[0]):
+                vidx = np.where(np.isin(self.sample_id,p))[0]
+                if len(vidx)>subsample:
+                    if subsample_by_freq is False:
+                        vidx = np.random.choice(vidx,subsample,replace=False)
+                    else:
+                        vidx = np.random.choice(vidx,subsample,replace=False,p=self.freq[vidx]/np.sum(self.freq[vidx]))
+                var_idx.append(vidx)
+            var_idx = np.hstack(var_idx)
+
         lb = LabelEncoder()
         lb.fit(vars[0])
         _,_,sample_idx = np.intersect1d(lb.classes_,vars[0],return_indices=True)
@@ -657,7 +671,7 @@ def Run_Graph_WF(set,sess,self,GO,batch_size,batch_size_update,random=True,train
         sp = OH.fit_transform(i.reshape(-1, 1)).T
         sp = sp.tocoo()
         indices = np.mat([sp.row, sp.col]).T
-        sp = tf.SparseTensorValue(indices, sp.data, sp.shape)
+        sp = tf.compat.v1.SparseTensorValue(indices, sp.data, sp.shape)
 
         # feed_dict = {GO.Y: vars[-1],
         #              GO.X_Freq: self.freq[var_idx],
@@ -667,9 +681,11 @@ def Run_Graph_WF(set,sess,self,GO,batch_size,batch_size_update,random=True,train
 
         feed_dict = {GO.Y: vars[-1],
                      GO.X_Freq: self.freq[var_idx],
-                     GO.X_Counts: self.counts[var_idx],
                      GO.sp: sp}
 
+        if hasattr(self,'counts'):
+            feed_dict[GO.X_Counts] = self.counts[var_idx]
+
         if drop_out_rate is not None:
             feed_dict[GO.prob] = drop_out_rate
 
@@ -781,12 +797,14 @@ def Get_Sequence_Pred(self,batch_size,GO,sess):
         sp = OH.fit_transform(i[var_idx].reshape(-1, 1)).T
         sp = sp.tocoo()
         indices = np.mat([sp.row, sp.col]).T
-        sp = tf.SparseTensorValue(indices, sp.data, sp.shape)
+        sp = tf.compat.v1.SparseTensorValue(indices, sp.data, sp.shape)
 
         feed_dict = {GO.X_Freq: freq[var_idx],
-                     GO.X_Counts: self.counts[var_idx],
                      GO.sp: sp}
 
+        if hasattr(self,'counts'):
+            feed_dict[GO.X_Counts] = self.counts[var_idx]
+
         if self.use_alpha is True:
             feed_dict[GO.X_Seq_alpha] = self.X_Seq_alpha[var_idx]
         if self.use_beta is True:
@@ -898,7 +916,7 @@ def Get_Sequence_Pred_GCN(self,batch_size,GO,sess):
         sp = OH.fit_transform(i[var_idx].reshape(-1, 1)).T
         sp = sp.tocoo()
         indices = np.mat([sp.row, sp.col]).T
-        sp = tf.SparseTensorValue(indices, sp.data, sp.shape)
+        sp = tf.compat.v1.SparseTensorValue(indices, sp.data, sp.shape)
 
         feed_dict = {GO.X_Freq: freq[var_idx],
                      GO.sp: sp,
@@ -998,13 +1016,13 @@ def _inf_ss(data,model='model_0'):
     batch_size = data.batch_size
     get = data.get
 
-    tf.reset_default_graph()
-    config = tf.ConfigProto(allow_soft_placement=True)
+    tf.compat.v1.reset_default_graph()
+    config = tf.compat.v1.ConfigProto(allow_soft_placement=True)
     config.gpu_options.allow_growth = True
     with tf.device(self.device):
-        saver = tf.train.import_meta_graph(os.path.join(self.Name, 'models', model, 'model.ckpt.meta'),clear_devices=True)
-    graph = tf.get_default_graph()
-    with tf.Session(graph=graph,config=config) as sess:
+        saver = tf.compat.v1.train.import_meta_graph(os.path.join(self.Name, 'models', model, 'model.ckpt.meta'),clear_devices=True)
+    graph = tf.compat.v1.get_default_graph()
+    with tf.compat.v1.Session(graph=graph,config=config) as sess:
         saver.restore(sess, tf.train.latest_checkpoint(os.path.join(self.Name, 'models', model)))
 
         if self.use_alpha is True:
